@@ -14,9 +14,9 @@ from shutil import copy2
 from email.utils import formatdate
 from enum import Enum
 
-__version__ = '2.202102'
+__version__ = '2.202202'
 __dhlib__ = '/usr/share/debhelper/dh_make'
-policy_version = '4.6.0'
+policy_version = '4.6.1'
 
 
 def check_dhlib_path():
@@ -67,26 +67,24 @@ def process_dhlib(args, subs_func, subdir, destdir=''):
     Recursively find all template files in the specified DHLIB directory
     and process them into our debian directory
     '''
-    for f in os.listdir(os.path.join(__dhlib__, subdir)):
-        file = os.path.join(__dhlib__, subdir, f)
-
-        if os.path.isdir(file):
-            process_dhlib(args, subs_func, os.path.join(subdir, f), f)
-        else:
-            process_file(args, subs_func, file, os.path.join(destdir, f))
+    process_dir(args, subs_func, subdir, destdir, __dhlib__)
 
 
-def process_dir(args, subs_func, adir, destdir=''):
+def process_dir(args, subs_func, adir, destdir='', root=''):
     '''
     Recursively find all templates in custom directory
     and process them into our debian directory
     '''
-    for f in os.listdir(adir):
-        file = os.path.join(adir, f)
+    fulldir = os.path.join(root, adir)
+
+    for f in os.listdir(fulldir):
+        file = os.path.join(fulldir, f)
         dest = os.path.join(destdir, f)
+
         if os.path.isdir(file):
-            os.mkdir(dest, 0o755)
-            process_dir(args, subs_func, file, dest)
+            if not os.path.exists(dest):
+                os.mkdir(dest, 0o755)
+            process_dir(args, subs_func, file, dest, root)
         else:
             process_file(args, subs_func, file, dest)
 
@@ -665,22 +663,20 @@ def setup_python(subs):
     subs['RULES_START_TEXT'] = 'export PYBUILD_NAME={}\n'.format(
         subs['PACKAGE'])
     subs['RULES_END_TEXT'] = '''
-# If you need to rebuild the Sphinx documentation
-# Add sphinxdoc to the dh --with line
+# If you need to rebuild the Sphinx documentation:
+# Add sphinxdoc to the dh --with line.
 #
-# And uncomment the following lines
-#override_dh_auto_build: export http_proxy=127.0.0.1:9
-#override_dh_auto_build: export https_proxy=127.0.0.1:9
-#override_dh_auto_build:
-#\tdh_auto_build
+# And uncomment the following lines.
+#execute_after_dh_auto_build-indep: export http_proxy=127.0.0.1:9
+#execute_after_dh_auto_build-indep: export https_proxy=127.0.0.1:9
+#execute_after_dh_auto_build-indep:
 #\tPYTHONPATH=. python3 -m sphinx -N -bhtml \\
 #\tdocs/ build/html # HTML generator
 #\tPYTHONPATH=. python3 -m sphinx -N -bman \\
 #\tdocs/ build/man # Manpage generator'''
-    subs['DH_ADDON'] += ' --with python3'\
-        ' --buildsystem=pybuild'
+    subs['DH_ADDON'] += ' --buildsystem=pybuild'
     subs['BUILD_DEPS'].extend([
-        'dh-python',
+        'dh-sequence-python3',
         'python3-setuptools',
         'python3-all',
     ])
@@ -755,19 +751,19 @@ def do_debianize(args, subs):
         setup_python(subs)
     else:
         subs['RULES_START_TEXT'] = '''
-# see FEATURE AREAS in dpkg-buildflags(1)
+# See FEATURE AREAS in dpkg-buildflags(1).
 #export DEB_BUILD_MAINT_OPTIONS = hardening=+all
 
-# see ENVIRONMENT in dpkg-buildflags(1)
-# package maintainers to append CFLAGS
+# See ENVIRONMENT in dpkg-buildflags(1).
+# Package maintainers to append CFLAGS.
 #export DEB_CFLAGS_MAINT_APPEND  = -Wall -pedantic
-# package maintainers to append LDFLAGS
+# Package maintainers to append LDFLAGS.
 #export DEB_LDFLAGS_MAINT_APPEND = -Wl,--as-needed
 
 '''
         subs['RULES_END_TEXT'] = '''
-# dh_make generated override targets
-# This is example for Cmake (See https://bugs.debian.org/641051 )
+# dh_make generated override targets.
+# This is an example for Cmake (see <https://bugs.debian.org/641051>).
 #override_dh_auto_configure:
 #\tdh_auto_configure -- \\
 #\t-DCMAKE_LIBRARY_PATH=$(DEB_HOST_MULTIARCH)'''
@@ -798,7 +794,7 @@ def do_debianize(args, subs):
         exit(1)
 
     # Translate the lists to strings
-    subs['BUILD_DEPS'] = ', '.join(subs['BUILD_DEPS'])
+    subs['BUILD_DEPS'] = ',\n '.join(subs['BUILD_DEPS']) + ","
     subs_func = make_subs_func(subs)
 
     if not args.defaultless:
@@ -810,6 +806,8 @@ def do_debianize(args, subs):
         # native packages don't have a watch file #806672
         if args.native:
             os.unlink('watch.ex')
+            os.unlink('upstream/metadata.ex')
+            os.rmdir('upstream')
 
         # Files specific to package classes
         process_dhlib(args, subs_func, 'debian' + args.package_class.value)
